@@ -177,10 +177,10 @@ class mysql:
               nada=0
 
       if(valid):
-        out().print('intentos:' + str(looper) + '; df.shape:' + str(df.shape) )
+        #out().print('intentos:' + str(looper) + '; df.shape:' + str(df.shape) )
         return {'result':1,'data':df}
       else:
-        out().print('Err mysql; intentos:' + str(looper) )
+        #out().print('Err mysql; intentos:' + str(looper) )
         return {'result':0,'data':pd.DataFrame()}
 
 
